<template>
  <div class="history-simulation">
    <div class="left-top">
      <span>预测模拟</span>
      <span class="clickable-text" @click="toggleDetails">{{
        isCollapsed ? "展开" : "收起"
      }}</span>
    </div>
    <div class="details" :class="{ hidden: isCollapsed }">
      <div class="input-item">
        <label>预测数据:</label>
        <el-select
          v-model="selectedForecastData"
          placeholder="请选择"
          popper-class="mySelectStyle"
        >
          <el-option
            v-for="item in ForecastData"
            :key="item.id"
            :label="item.name"
            :value="item.id"
          ></el-option>
        </el-select>
      </div>
      <div class="input-item">
        <label>方案名称:</label>
        <el-input
          v-model="schemeName"
          type="text"
          placeholder="请输入"
        ></el-input>
      </div>
      <div class="input-item" style="margin-bottom: 10px">
        <label>降雨雨量:</label>
        <el-input
          v-model="totalRainfall"
          type="number"
          placeholder="请输入"
        ></el-input>
        <span>mm</span>
      </div>
      <div class="input-item" style="margin-bottom: 10px">
        <label>降雨强度:</label>
        <el-input
          v-model="rainfallIntensity"
          type="number"
          placeholder="请输入"
        ></el-input>
        <span>mm/h</span>
      </div>
      <div class="input-item">
        <label>降雨模式:</label>
        <el-select
          v-model="selectedRainfallPatterns"
          placeholder="请选择"
          popper-class="mySelectStyle"
        >
          <el-option
            v-for="item in RainfallPatterns"
            :key="item.id"
            :label="item.name"
            :value="item.id"
          ></el-option>
        </el-select>
      </div>
      <div class="input-item">
        <label>预计时长:</label>
        <el-input
          v-model="rainfallDuration"
          type="number"
          placeholder="请输入"
        ></el-input>
        <span>h</span>
      </div>
      <!-- <div>
          <label>仿真参数:</label>
          <div style="width: 100%; height: 43px; background-color: #fff;"></div>
        </div> -->
    </div>
    <div class="buttons">
      <el-button type="primary" @click="openPlan">打开方案</el-button>
      <el-button type="primary" @click="openSaveDialog">保存方案</el-button>
      <el-button type="success" @click="startPlay">开始模拟</el-button>
    </div>

    <!-- 保存方案对话框 -->
    <el-dialog
      v-model="saveDialogVisible"
      title="保存方案"
      width="50%"
      :before-close="handleClose"
      custom-class="custom-dialog"
    >
      <div class="dialog-content">
        <p><strong>方案名称：</strong>{{ schemeName }}</p>
        <p><strong>所选重点沟：</strong>{{ props.selectedArea }}</p>
        <p><strong>模拟类型：</strong>预测模拟</p>
        <p><strong>预测数据：</strong>{{ selectedForecastDataName }}</p>
        <p><strong>降雨雨量：</strong>{{ totalRainfall }} mm</p>
        <p><strong>降雨强度：</strong>{{ rainfallIntensity }} mm/h</p>
        <p><strong>降雨模式：</strong>{{ selectedRainfallPatternsName }}</p>
        <p><strong>预计时长：</strong>{{ rainfallDuration }} h</p>
      </div>
      <template #footer>
        <span class="dialog-footer">
          <el-button @click="saveDialogVisible = false">取消</el-button>
          <el-button type="primary" @click="confirmSave">确定保存</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import { ref, computed, inject } from "vue";
import { ElMessage } from "element-plus";
import { initeWaterPrimitiveView } from "@/utils/water";
import { useSimStore } from "@/store/simulation.js"; // 引入 Store
import { SimAPIStore } from "@/store/simAPI";

// 获取 Store 实例
const simStore = SimAPIStore();

// 注入模拟操作方法
const { startSimulate, endSimulate } = inject("simulateActions");

function startPlay() {
  console.log("开始模拟按钮被点击");
  console.log("当前选中的区域：", props.selectedArea);
  initeWaterPrimitiveView();
  startSimulate();
}

// 定义 Props
const props = defineProps({
  selectedArea: {
    type: String,
    required: true,
  },
});

// 数据绑定
const isCollapsed = ref(false); // 控制展开/收起状态
const totalRainfall = ref(50); // 降雨雨量
const schemeName = ref("方案名称"); // 方案名称
const rainfallIntensity = ref(70); // 降雨强度
const rainfallDuration = ref(5); // 预计时长
const selectedForecastData = ref("4"); // 默认选中“自定义参数”
const selectedRainfallPatterns = ref("1"); // 默认选中“正态分布”
const saveDialogVisible = ref(false); // 控制保存方案对话框的显示状态

// 预测数据选项
const ForecastData = [
  { id: "1", name: "降雨场次" },
  { id: "2", name: "气象数据" },
  { id: "3", name: "逐小时预报数据" },
  { id: "4", name: "自定义参数" },
];

// 降雨模式选项
const RainfallPatterns = [
  { id: "1", name: "正态分布" },
  { id: "2", name: "平均分布" },
  { id: "3", name: "波动平均分布" },
  { id: "4", name: "持续上升" },
];

// 计算属性：获取当前选中的预测数据名称
const selectedForecastDataName = computed(() => {
  const selected = ForecastData.find(
    (item) => item.id === selectedForecastData.value
  );
  return selected ? selected.name : "";
});

// 计算属性：获取当前选中的降雨模式名称
const selectedRainfallPatternsName = computed(() => {
  const selected = RainfallPatterns.find(
    (item) => item.name === selectedRainfallPatterns.value
  );
  return selected ? selected.name : "";
});

// 切换详情显示
const toggleDetails = () => {
  isCollapsed.value = !isCollapsed.value;
};
// const simStore = SimAPIStore();

// 打开保存方案对话框
const openSaveDialog = async () => {
  const forms = {
    name: schemeName.value,
    type: 1,
    rainfall: totalRainfall.value,
    duration: rainfallDuration.value,
    intensity: rainfallIntensity.value,
    mode: selectedRainfallPatterns.value,
    prediction: selectedForecastDataName.value,
  };
  console.log(forms, "forms");
  await simStore.addSimCheme(forms);
  // if (
  //   !props.selectedArea ||
  //   !selectedForecastData.value ||
  //   !schemeName.value ||
  //   !totalRainfall.value ||
  //   !rainfallIntensity.value ||
  //   !selectedRainfallPatterns.value ||
  //   !rainfallDuration.value
  // ) {
  //   ElMessage.warning("请先填写所有必填项");
  //   return;
  // }
  // saveDialogVisible.value = true;
};

// 关闭保存方案对话框
const handleClose = () => {
  saveDialogVisible.value = false;
};

// 确认保存
const confirmSave = () => {
  // 构造新的方案对象
  const newScheme = {
    id: Date.now().toString(), // 唯一 ID
    area: props.selectedArea, // 区域
    name: selectedForecastDataName.value, // 方案名称（预测数据类型）
    createTime: new Date().toISOString(), // 创建时间
    taskStatus: 1, // 初始状态为未开始
    simulationType: "预测模拟", // 模拟类型
    forecastData: selectedForecastDataName.value, // 预测数据
    totalRainfall: `${totalRainfall.value} mm`, // 降雨雨量
    schemeName: schemeName.value, // 降雨总量
    rainfallIntensity: `${rainfallIntensity.value} mm/h`, // 降雨强度
    rainfallPattern: selectedRainfallPatternsName.value, // 降雨模式
    rainfallDuration: `${rainfallDuration.value} h`, // 预计时长
  };

  // 调用 Store 的方法添加方案
  simStore.addSchemCard(newScheme);

  console.log("保存方案成功", newScheme);
  ElMessage.success("方案已保存");

  // 关闭对话框
  saveDialogVisible.value = false;
};

// 打开方案
const openPlan = () => {
  console.log("打开方案按钮被点击");
};
</script>

<style scoped>
.history-simulation {
  margin-bottom: 20px;
}

.details {
  margin-top: 10px;
  transition: height 0.3s ease, opacity 0.3s ease;
  overflow: hidden;
}

.hidden {
  height: 0;
  opacity: 0;
}

.buttons {
  margin-top: 10px;
  display: flex;
  gap: 10px;
}
.el-button {
  flex: 1;
}
.input-item {
  display: flex;
  align-items: center;
}

label {
  text-align: left;
  white-space: nowrap;
  margin-right: 10px;
}

.el-input {
  flex: 4;
}

span {
  flex: 1;
  text-align: left;
}

.el-select {
  flex: 4;
  text-align: left;
  margin-bottom: 10px;
}

.clickable-text {
  margin-left: 160px;
  cursor: pointer;
  font-size: 14px;
  color: #61f7d4;
}

/* 自定义 Dialog 的 z-index */
.custom-dialog {
  z-index: 3000 !important; /* 确保对话框覆盖其他元素 */
}
</style>
